@@ -145,12 +145,13 @@ class model(coordinates.Coordinates):
                                          no_ter, True, extra_data)
 
     def build_sequence(self, sequence, special_patches=None,
-                       patch_default=True):
+                       patch_default=True, blank_single_chain=True):
         """Build an extended chain from a string of one-letter residue codes"""
         a = alignment.alignment(self.env)
-        a.append_sequence(sequence)
+        a.append_sequence(sequence, blank_single_chain)
         self.clear_topology()
-        self.generate_topology(a[0], patch_default=patch_default)
+        self.generate_topology(a[0], patch_default=patch_default,
+                               blank_single_chain=blank_single_chain)
         if special_patches:
             special_patches(self)
         self.build(initialize_xyz=True, build_method='INTERNAL_COORDINATES')
@@ -241,10 +242,11 @@ class model(coordinates.Coordinates):
         return _modeller.mod_model_to_iupac(self.modpt, self.env.libs.modpt)
 
     def clear_topology(self):
-        """Clear all covalent topology (atomic connectivitiy) and sequence"""
+        """Clear all covalent topology (atomic connectivity) and sequence"""
         return _modeller.mod_model_topology_clear(self.modpt)
 
-    def generate_topology(self, alnseq, patch_default=None, io=None):
+    def generate_topology(self, alnseq, patch_default=None,
+                          blank_single_chain=True, io=None):
         """Generate covalent topology (atomic connectivity) and sequence"""
         if not isinstance(alnseq, alnsequence.Sequence):
             raise TypeError("""Must use an alignment 'Sequence' object here.
@@ -254,9 +256,10 @@ For example, replace 'generate_topology(aln, sequence="foo")' with
             io = self.env.io
         if patch_default is None:
             patch_default = self.env.patch_default
-        func = _modeller.mod_model_topology_generate
+        func = _modeller.mod_model_topology_generate2
         return func(self.modpt, alnseq.aln.modpt, io.modpt,
-                    self.env.libs.modpt, alnseq._num, patch_default)
+                    self.env.libs.modpt, alnseq._num, patch_default,
+                    blank_single_chain)
 
     def patch(self, residue_type, residues):
         """Patch the model topology"""
